# SpecOneD
##### (Version 1.0.0)

[![Documentation Status](https://readthedocs.org/projects/speconed/badge/?version=latest)](https://speconed.readthedocs.io/en/latest/?badge=latest)

SpecOneD is a lightweight python package that introduces the SpecOneD class for the manipulation of one-dimensional astronomical spectra.

For installation instructions and documentation visit [SpecOneD's ReadTheDocs]



[SpecOneD's ReadTheDocs]: https://speconed.readthedocs.io/en/latest/